pitchtools.transpose_chromatic_pitch_by_melodic_chromatic_interval_segment
==========================================================================

.. autofunction:: abjad.tools.pitchtools.transpose_chromatic_pitch_by_melodic_chromatic_interval_segment.transpose_chromatic_pitch_by_melodic_chromatic_interval_segment
